@@ -1,33 +1,36 @@
-import os
-import json
-import queue
 import ctypes
+import json
+import os
+import queue
 import subprocess
 
 from wrapt import synchronized
 
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import KiwoomOpenApiPlusError
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import KiwoomOpenApiPlusNegativeReturnCodeError
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusRateLimiter import KiwoomOpenApiPlusCommRqDataRateLimiter
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusRateLimiter import KiwoomOpenApiPlusSendConditionRateLimiter
-
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import (
+    KiwoomOpenApiPlusError,
+    KiwoomOpenApiPlusNegativeReturnCodeError,
+)
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusRateLimiter import (
+    KiwoomOpenApiPlusCommRqDataRateLimiter,
+    KiwoomOpenApiPlusSendConditionRateLimiter,
+)
 from koapy.utils.logging.Logging import Logging
 from koapy.utils.subprocess import function_to_subprocess_args
 
-class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
 
+class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
     def GetServerGubun(self):
-        return self.GetLoginInfo('GetServerGubun')
+        return self.GetLoginInfo("GetServerGubun")
 
     def ShowAccountWindow(self):
-        return self.KOA_Functions('ShowAccountWindow', '')
+        return self.KOA_Functions("ShowAccountWindow", "")
 
     def GetCodeListByMarketAsList(self, market=None):
         if market is None:
-            market = ''
+            market = ""
         market = str(market)
-        result = self.GetCodeListByMarket(market).rstrip(';')
-        result = result.split(';') if result else []
+        result = self.GetCodeListByMarket(market).rstrip(";")
+        result = result.split(";") if result else []
         return result
 
     def GetNameListByMarketAsList(self, market):
@@ -36,12 +39,12 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
         return names
 
     def GetUserId(self):
-        userid = self.GetLoginInfo('USER_ID')
+        userid = self.GetLoginInfo("USER_ID")
         return userid
 
     def GetAccountList(self):
-        accounts = self.GetLoginInfo('ACCLIST').rstrip(';')
-        accounts = accounts.split(';') if accounts else []
+        accounts = self.GetLoginInfo("ACCLIST").rstrip(";")
+        accounts = accounts.split(";") if accounts else []
         return accounts
 
     def GetFirstAvailableAccount(self):
@@ -53,26 +56,28 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
 
     def GetMasterStockStateAsList(self, code):
         states = self.GetMasterStockState(code).strip()
-        states = states.split('|') if states else []
+        states = states.split("|") if states else []
         return states
 
     def GetKospiCodeList(self):
-        codes = self.GetCodeListByMarketAsList('0')
+        codes = self.GetCodeListByMarketAsList("0")
         codes = sorted(codes)
         return codes
 
     def GetKosdaqCodeList(self):
-        codes = self.GetCodeListByMarketAsList('10')
+        codes = self.GetCodeListByMarketAsList("10")
         codes = sorted(codes)
         return codes
 
-    def GetGeneralCodeList(self,
-            include_preferred_stock=False,
-            include_etn=False,
-            include_etf=False,
-            include_mutual_fund=False,
-            include_reits=False,
-            include_kosdaq=False):
+    def GetGeneralCodeList(
+        self,
+        include_preferred_stock=False,
+        include_etn=False,
+        include_etf=False,
+        include_mutual_fund=False,
+        include_reits=False,
+        include_kosdaq=False,
+    ):
         """
         [시장구분값]
           0 : 장내
@@ -91,13 +96,16 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
 
         # 코드 마지막 자리가 0 이 아니면 우선주일 가능성이 있다고 보고 제외
         if not include_preferred_stock:
-            codes = [code for code in codes if code.endswith('0')]
+            codes = [code for code in codes if code.endswith("0")]
 
         # 장내 시장에서 ETN 이 섞여 있는데 시장구분값으로 뺄 수가 없어서 이름을 보고 대충 제외
         if not include_etn:
             names = [self.GetMasterCodeName(code) for code in codes]
-            etn_suffixes = ['ETN', 'ETN(H)', 'ETN B', 'ETN(H) B']
-            is_not_etn_name = [not any(name.endswith(suffix) for suffix in etn_suffixes) for name in names]
+            etn_suffixes = ["ETN", "ETN(H)", "ETN B", "ETN(H) B"]
+            is_not_etn_name = [
+                not any(name.endswith(suffix) for suffix in etn_suffixes)
+                for name in names
+            ]
             codes = [code for code, cond in zip(codes, is_not_etn_name) if cond]
 
         # 코드값 기준 제외 준비
@@ -105,13 +113,13 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
 
         # 나머지는 혹시나 겹치는 애들이 나올 수 있는 시장에서 코드기준 제외
         if not include_kosdaq:
-            codes = codes - set(self.GetCodeListByMarketAsList('10')) # 코스닥
+            codes = codes - set(self.GetCodeListByMarketAsList("10"))  # 코스닥
         if not include_etf:
-            codes = codes - set(self.GetCodeListByMarketAsList('8'))  # ETF
+            codes = codes - set(self.GetCodeListByMarketAsList("8"))  # ETF
         if not include_mutual_fund:
-            codes = codes - set(self.GetCodeListByMarketAsList('4'))  # 뮤추얼펀드
+            codes = codes - set(self.GetCodeListByMarketAsList("4"))  # 뮤추얼펀드
         if not include_reits:
-            codes = codes - set(self.GetCodeListByMarketAsList('6'))  # 리츠
+            codes = codes - set(self.GetCodeListByMarketAsList("6"))  # 리츠
 
         # 정렬된 리스트 형태로 제공
         codes = sorted(list(codes))
@@ -119,33 +127,37 @@ class KiwoomOpenApiPlusSimpleQAxWidgetMixin:
         return codes
 
     def IsSuspended(self, code):
-        return '거래정지' in self.GetMasterStockStateAsList(code)
+        return "거래정지" in self.GetMasterStockStateAsList(code)
 
     def IsInSupervision(self, code):
-        return '관리종목' in self.GetMasterStockStateAsList(code)
+        return "관리종목" in self.GetMasterStockStateAsList(code)
 
     def IsInSurveillance(self, code):
-        return '감리종목' in self.GetMasterStockStateAsList(code)
+        return "감리종목" in self.GetMasterStockStateAsList(code)
 
     def GetConditionFilePath(self):
         modulepath = self.GetAPIModulePath()
         userid = self.GetUserId()
-        condition_filepath = os.path.join(modulepath, 'system', '%s_NewSaveIndex.dat' % userid)
+        condition_filepath = os.path.join(
+            modulepath, "system", "%s_NewSaveIndex.dat" % userid
+        )
         return condition_filepath
 
     def GetConditionNameListAsList(self):
         self.EnsureConditionLoaded()
         conditions = self.GetConditionNameList()
-        conditions = conditions.rstrip(';').split(';') if conditions else []
-        conditions = [cond.split('^') for cond in conditions]
+        conditions = conditions.rstrip(";").split(";") if conditions else []
+        conditions = [cond.split("^") for cond in conditions]
         conditions = [(int(cond[0]), cond[1]) for cond in conditions]
         return conditions
 
-class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
+class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
     def __init__(self):
         self._comm_rate_limiter = KiwoomOpenApiPlusCommRqDataRateLimiter()
-        self._cond_rate_limiter = KiwoomOpenApiPlusSendConditionRateLimiter(self._comm_rate_limiter)
+        self._cond_rate_limiter = KiwoomOpenApiPlusSendConditionRateLimiter(
+            self._comm_rate_limiter
+        )
 
         self._is_condition_loaded = False
 
@@ -154,7 +166,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
     def DisableAutoLogin(self):
         module_path = self.GetAPIModulePath()
-        autologin_dat = os.path.join(module_path, 'system', 'Autologin.dat')
+        autologin_dat = os.path.join(module_path, "system", "Autologin.dat")
         if os.path.exists(autologin_dat):
             os.remove(autologin_dat)
 
@@ -164,90 +176,98 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
         if credential is None:
             from koapy.config import config
-            credential = config.get('koapy.backend.kiwoom_open_api_plus.credential')
+
+            credential = config.get("koapy.backend.kiwoom_open_api_plus.credential")
 
         is_in_development = False
         use_set_text = False
 
-        userid = credential.get('user_id')
-        password = credential.get('user_password')
-        cert = credential.get('cert_password')
+        userid = credential.get("user_id")
+        password = credential.get("user_password")
+        cert = credential.get("cert_password")
 
         is_save_userid = True
-        is_simulation = credential.get('is_simulation')
+        is_simulation = credential.get("is_simulation")
 
         desktop = pywinauto.Desktop(allow_magic_lookup=False)
-        login_window = desktop.window(title='Open API Login')
+        login_window = desktop.window(title="Open API Login")
 
         try:
-            cls.logger.info('Waiting for login screen')
+            cls.logger.info("Waiting for login screen")
             timeout_login_screen_ready = 30
-            login_window.wait('ready', timeout_login_screen_ready)
+            login_window.wait("ready", timeout_login_screen_ready)
         except pywinauto.timings.TimeoutError:
-            cls.logger.info('Cannot find login screen')
+            cls.logger.info("Cannot find login screen")
             raise
         else:
-            cls.logger.info('Login screen found')
+            cls.logger.info("Login screen found")
             if is_in_development:
                 login_window.print_control_identifiers()
 
             if userid:
-                cls.logger.info('Putting userid')
+                cls.logger.info("Putting userid")
                 if use_set_text:
-                    login_window['Edit1'].set_text(userid)
+                    login_window["Edit1"].set_text(userid)
                 else:
-                    login_window['Edit1'].set_focus()
+                    login_window["Edit1"].set_focus()
                     pywinauto.keyboard.send_keys(userid)
-                    pywinauto.keyboard.send_keys('{TAB}')
+                    pywinauto.keyboard.send_keys("{TAB}")
             if password:
-                cls.logger.info('Putting password')
+                cls.logger.info("Putting password")
                 if use_set_text:
-                    login_window['Edit2'].set_text(password)
+                    login_window["Edit2"].set_text(password)
                 else:
-                    login_window['Edit2'].set_focus()
+                    login_window["Edit2"].set_focus()
                     pywinauto.keyboard.send_keys(password)
-                    pywinauto.keyboard.send_keys('{TAB}')
+                    pywinauto.keyboard.send_keys("{TAB}")
             else:
                 raise RuntimeError("'user_password' not set, please check credential")
 
             if is_save_userid:
-                cls.logger.info('Checking to save userid')
-                login_window['Button6'].check() # check doesn't work
+                cls.logger.info("Checking to save userid")
+                login_window["Button6"].check()  # check doesn't work
             else:
-                cls.logger.info('Unchecking to save userid')
-                login_window['Button6'].uncheck() # uncheck doesn't work
+                cls.logger.info("Unchecking to save userid")
+                login_window["Button6"].uncheck()  # uncheck doesn't work
 
             if not is_simulation:
-                if not login_window['Edit3'].is_enabled():
-                    cls.logger.info('Unchecking to use simulation server')
-                    login_window['Button5'].uncheck_by_click()
+                if not login_window["Edit3"].is_enabled():
+                    cls.logger.info("Unchecking to use simulation server")
+                    login_window["Button5"].uncheck_by_click()
                 if cert:
-                    cls.logger.info('Putting cert password')
+                    cls.logger.info("Putting cert password")
                     if use_set_text:
-                        login_window['Edit3'].set_text(cert)
+                        login_window["Edit3"].set_text(cert)
                     else:
-                        login_window['Edit3'].set_focus()
+                        login_window["Edit3"].set_focus()
                         pywinauto.keyboard.send_keys(cert)
-                        pywinauto.keyboard.send_keys('{TAB}')
+                        pywinauto.keyboard.send_keys("{TAB}")
                 else:
-                    raise RuntimeError("'cert_password' not set, please check credential")
+                    raise RuntimeError(
+                        "'cert_password' not set, please check credential"
+                    )
             else:
-                if login_window['Edit3'].is_enabled():
-                    cls.logger.info('Checking to use simulation server')
-                    login_window['Button5'].check_by_click()
+                if login_window["Edit3"].is_enabled():
+                    cls.logger.info("Checking to use simulation server")
+                    login_window["Button5"].check_by_click()
 
-            cls.logger.info('Logging in')
-            login_window['Button1'].click()
+            cls.logger.info("Logging in")
+            login_window["Button1"].click()
 
     @classmethod
     def LoginUsingPywinauto_RunScriptInSubprocess(cls, credential=None):
         def main():
             # pylint: disable=redefined-outer-name,reimported,import-self
-            import sys
             import json
-            from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusQAxWidgetMixin import KiwoomOpenApiPlusQAxWidgetMixin
+            import sys
+
+            from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusQAxWidgetMixin import (
+                KiwoomOpenApiPlusQAxWidgetMixin,
+            )
+
             credential = json.load(sys.stdin)
             KiwoomOpenApiPlusQAxWidgetMixin.LoginUsingPywinauto_Impl(credential)
+
         args = function_to_subprocess_args(main)
         return subprocess.run(args, input=json.dumps(credential), text=True, check=True)
 
@@ -256,10 +276,14 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
     def Connect(self, credential=None):
         if credential is not None:
-            assert self.IsAdmin(), 'Connect() method requires to be run as administrator, if credential is given explicitly'
+            assert (
+                self.IsAdmin()
+            ), "Connect() method requires to be run as administrator, if credential is given explicitly"
         q = queue.Queue()
+
         def OnEventConnect(errcode):
             q.put(errcode)
+
         self.OnEventConnect.connect(OnEventConnect)
         try:
             if credential is not None:
@@ -273,12 +297,12 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         return errcode
 
     def EnsureConnected(self, credential=None):
-        errcode = 0 # pylint: disable=unused-variable
+        errcode = 0  # pylint: disable=unused-variable
         status = self.GetConnectState()
         if status == 0:
             errcode = self.Connect(credential)
             status = self.GetConnectState()
-        assert status == 1, 'Could not ensure connected'
+        assert status == 1, "Could not ensure connected"
         return status
 
     def IsConnected(self):
@@ -286,19 +310,22 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
 
     def LoadCondition(self):
         q = queue.Queue()
+
         def OnReceiveConditionVer(ret, msg):
             if not ret:
                 q.put(KiwoomOpenApiPlusError(msg))
             else:
                 q.put((ret, msg))
+
         self.OnReceiveConditionVer.connect(OnReceiveConditionVer)
         try:
             return_code = KiwoomOpenApiPlusError.try_or_raise_boolean(
-                self.GetConditionLoad(), 'Failed to load condition')
+                self.GetConditionLoad(), "Failed to load condition"
+            )
             res = q.get()
             if isinstance(res, KiwoomOpenApiPlusError):
                 raise res
-        except: # pylint: disable=try-except-raise
+        except:  # pylint: disable=try-except-raise
             raise
         else:
             if return_code == 1:
@@ -324,7 +351,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
             return_code = self.LoadCondition()
         else:
             return_code = 1
-        assert return_code == 1, 'Could not ensure condition loaded'
+        assert return_code == 1, "Could not ensure condition loaded"
         return return_code
 
     @synchronized
@@ -332,7 +359,7 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         if inputs:
             for k, v in inputs.items():
                 self.SetInputValue(k, v)
-        prevnext = int(prevnext) # ensure prevnext is int
+        prevnext = int(prevnext)  # ensure prevnext is int
         code = self.CommRqData(rqname, trcode, prevnext, scrnno)
         return code
 
@@ -349,7 +376,9 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         self._comm_rate_limiter.sleep_if_necessary()
         return self.AtomicCommRqData(rqname, trcode, prevnext, scrnno, inputs)
 
-    def RateLimitedCommKwRqData(self, codes, prevnext, codecnt, typeflag, rqname, scrnno):
+    def RateLimitedCommKwRqData(
+        self, codes, prevnext, codecnt, typeflag, rqname, scrnno
+    ):
         """
         [조회제한]
           OpenAPI 조회는 1초당 5회로 제한되며 복수종목 조회와 조건검색 조회 횟수가 합산됩니다.
@@ -362,44 +391,60 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         self._comm_rate_limiter.sleep_if_necessary()
         return self.CommKwRqData(codes, prevnext, codecnt, typeflag, rqname, scrnno)
 
-    def RateLimitedCommRqDataAndCheck(self, rqname, trcode, prevnext, scrnno, inputs=None):
+    def RateLimitedCommRqDataAndCheck(
+        self, rqname, trcode, prevnext, scrnno, inputs=None
+    ):
         code = self.RateLimitedCommRqData(rqname, trcode, prevnext, scrnno)
 
-        spec = 'CommRqData(%r, %r, %r, %r)' % (rqname, trcode, prevnext, scrnno)
+        spec = "CommRqData(%r, %r, %r, %r)" % (rqname, trcode, prevnext, scrnno)
 
         if inputs is not None:
-            spec += ' with inputs %r' % inputs
+            spec += " with inputs %r" % inputs
 
         if code == KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_NONE:
-            message = 'CommRqData() was successful; ' + spec
+            message = "CommRqData() was successful; " + spec
             self.logger.debug(message)
         elif code == KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_SISE_OVERFLOW:
-            message = 'CommRqData() was rejected due to massive request; ' + spec
+            message = "CommRqData() was rejected due to massive request; " + spec
             self.logger.error(message)
             raise KiwoomOpenApiPlusNegativeReturnCodeError(code)
         elif code == KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_ORD_WRONG_INPUT:
-            message = 'CommRqData() failed due to wrong input, check if input was correctly set; ' + spec
+            message = (
+                "CommRqData() failed due to wrong input, check if input was correctly set; "
+                + spec
+            )
             self.logger.error(message)
             raise KiwoomOpenApiPlusNegativeReturnCodeError(code)
-        elif code in (KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_RQ_STRUCT_FAIL, KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_RQ_STRING_FAIL):
-            message = 'CommRqData() request was invalid; ' + spec
+        elif code in (
+            KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_RQ_STRUCT_FAIL,
+            KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_RQ_STRING_FAIL,
+        ):
+            message = "CommRqData() request was invalid; " + spec
             self.logger.error(message)
             raise KiwoomOpenApiPlusNegativeReturnCodeError(code)
         else:
-            message = 'Unknown error occured during CommRqData() request; ' + spec
-            korean_message = KiwoomOpenApiPlusNegativeReturnCodeError.get_error_message_by_code(code)
+            message = "Unknown error occured during CommRqData() request; " + spec
+            korean_message = (
+                KiwoomOpenApiPlusNegativeReturnCodeError.get_error_message_by_code(code)
+            )
             if korean_message is not None:
-                message += '; Korean error message: ' +  korean_message
+                message += "; Korean error message: " + korean_message
             self.logger.error(message)
             raise KiwoomOpenApiPlusNegativeReturnCodeError(code)
 
         return code
 
-    def RatedLimitedSendOrder(self, rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno):
+    def RatedLimitedSendOrder(
+        self, rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno
+    ):
         self._comm_rate_limiter.sleep_if_necessary()
-        return self.SendOrder(rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno)
+        return self.SendOrder(
+            rqname, scrnno, accno, ordertype, code, qty, price, hogagb, orgorderno
+        )
 
-    def RateLimitedSendCondition(self, scrnno, condition_name, condition_index, search_type):
+    def RateLimitedSendCondition(
+        self, scrnno, condition_name, condition_index, search_type
+    ):
         """
         [조회제한]
           OpenAPI 조회는 1초당 5회로 제한되며 복수종목 조회와 조건검색 조회 횟수가 합산됩니다.
@@ -412,6 +457,9 @@ class KiwoomOpenApiPlusComplexQAxWidgetMixin(Logging):
         self._cond_rate_limiter.sleep_if_necessary()
         return self.SendCondition(scrnno, condition_name, condition_index, search_type)
 
-class KiwoomOpenApiPlusQAxWidgetMixin(KiwoomOpenApiPlusSimpleQAxWidgetMixin, KiwoomOpenApiPlusComplexQAxWidgetMixin):
+
+class KiwoomOpenApiPlusQAxWidgetMixin(
+    KiwoomOpenApiPlusSimpleQAxWidgetMixin, KiwoomOpenApiPlusComplexQAxWidgetMixin
+):
 
     pass
