@@ -1,69 +1,77 @@
-# pylint: disable=no-member
-
-import time
-import datetime
-import logging
-import threading
 import collections
+import datetime
+import threading
+import time
 
 import backtrader as bt
-import pandas as pd
 import numpy as np
-
-from exchange_calendars import get_calendar
+import pandas as pd
 
 from backtrader import TimeFrame
 from backtrader.metabase import MetaParams
 from backtrader.utils.py3 import queue
+from exchange_calendars import get_calendar
 
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusEntrypoint import KiwoomOpenApiPlusEntrypoint
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import KiwoomOpenApiPlusError
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import KiwoomOpenApiPlusNegativeReturnCodeError
-from koapy.backtrader.KiwoomOpenApiPlusEventStreamer import KiwoomOpenApiPlusEventStreamer
-
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusEntrypoint import (
+    KiwoomOpenApiPlusEntrypoint,
+)
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError import (
+    KiwoomOpenApiPlusError,
+    KiwoomOpenApiPlusNegativeReturnCodeError,
+)
+from koapy.backtrader.KiwoomOpenApiPlusEventStreamer import (
+    KiwoomOpenApiPlusEventStreamer,
+)
 from koapy.utils.logging.Logging import Logging
 
-class KiwoomOpenApiPlusJsonError(KiwoomOpenApiPlusNegativeReturnCodeError):
 
+class KiwoomOpenApiPlusJsonError(KiwoomOpenApiPlusNegativeReturnCodeError):
     def __init__(self, code, message=None):
         if isinstance(code, KiwoomOpenApiPlusError):
             err = code
-            code = getattr(err, 'code', KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_FAIL)
+            code = getattr(
+                err, "code", KiwoomOpenApiPlusNegativeReturnCodeError.OP_ERR_FAIL
+            )
             message = err.message
         super().__init__(code, message)
 
     def error_response(self, description=None):
         response = {
-            'code': self.code,
-            'message': self.message,
-            'description': description or '',
+            "code": self.code,
+            "message": self.message,
+            "description": description or "",
         }
         return response
 
+
 class KiwoomOpenApiPlusTimeFrameError(KiwoomOpenApiPlusJsonError):
-
     def __init__(self):
-        super().__init__(code=597, message='Not supported TimeFrame')
+        super().__init__(code=597, message="Not supported TimeFrame")
 
-class HistoricalPriceRecord(collections.namedtuple('HistoricalPriceRecord', ['time', 'open', 'high', 'low', 'close', 'volume'])):
+
+class HistoricalPriceRecord(
+    collections.namedtuple(
+        "HistoricalPriceRecord", ["time", "open", "high", "low", "close", "volume"]
+    )
+):
 
     __slots__ = ()
 
-    _krx_timezone = get_calendar('XKRX').tz
+    _krx_timezone = get_calendar("XKRX").tz
 
     @classmethod
     def from_tuple(cls, tup):
-        if '일자' in tup._fields:
-            dt = datetime.datetime.strptime(tup.일자, '%Y%m%d')
+        if "일자" in tup._fields:
+            dt = datetime.datetime.strptime(tup.일자, "%Y%m%d")
             dt = cls._krx_timezone.localize(dt)
-            time = dt.timestamp() * (10 ** 6) # pylint: disable=redefined-outer-name
-        elif '체결시간' in tup._fields:
-            dt = datetime.datetime.strptime(tup.체결시간, '%Y%m%d%H%M%S')
+            time = dt.timestamp() * (10 ** 6)  # pylint: disable=redefined-outer-name
+        elif "체결시간" in tup._fields:
+            dt = datetime.datetime.strptime(tup.체결시간, "%Y%m%d%H%M%S")
             dt = cls._krx_timezone.localize(dt)
             time = dt.timestamp() * (10 ** 6)
         else:
-            raise KiwoomOpenApiPlusError('Cannot specify time')
-        open = abs(float(tup.시가)) # pylint: disable=redefined-builtin
+            raise KiwoomOpenApiPlusError("Cannot specify time")
+        open = abs(float(tup.시가))  # pylint: disable=redefined-builtin
         high = abs(float(tup.고가))
         low = abs(float(tup.저가))
         close = abs(float(tup.현재가))
@@ -78,12 +86,13 @@ class HistoricalPriceRecord(collections.namedtuple('HistoricalPriceRecord', ['ti
     def dict_records_from_dataframe(cls, df):
         return [msg._asdict() for msg in cls.records_from_dataframe(df)]
 
+
 class API:
 
     # 우선은 최대한 기존 Oanda 구현을 유지한채로 맞춰서 동작할 수 있도록 구현해놓고
     # 추후 동작이 되는게 확인되면 천천히 하단 API 에 맞게 최적화를 하는 방향으로 작업하는 것으로...
 
-    _krx_timezone = get_calendar('XKRX').tz
+    _krx_timezone = get_calendar("XKRX").tz
 
     def __init__(self, context):
         self._context = context
@@ -92,88 +101,105 @@ class API:
     def __getattr__(self, name):
         return getattr(self._context, name)
 
-    def get_instruments_original(self, account, instruments): # TODO: 계좌에 따라 시장이 다를 수 있음
+    def get_instruments_original(
+        self, account, instruments
+    ):  # TODO: 계좌에 따라 시장이 다를 수 있음
         instruments = self.GetStockInfoAsDataFrame(instruments)
         instruments = [tup._asdict() for tup in instruments.itertuples(index=False)]
-        response = {'instruments': instruments}
+        response = {"instruments": instruments}
         return response
 
     def get_instruments(self, account, instruments):
         if isinstance(instruments, str):
             instruments = [instruments]
         instruments = [inst for inst in instruments if inst in self._codes]
-        response = {'instruments': instruments}
+        response = {"instruments": instruments}
         return response
 
     def get_history(self, trcode, inputs, dtbegin=None, dtend=None):
-        if trcode == 'opt10079':
-            code = inputs['종목코드']
-            interval = inputs['틱범위']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetTickStockDataAsDataFrame(code, interval, dtend, dtbegin, adjusted_price=adjusted_price)
-        elif trcode == 'opt10080':
-            code = inputs['종목코드']
-            interval = inputs['틱범위']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetMinuteStockDataAsDataFrame(code, interval, dtend, dtbegin, adjusted_price=adjusted_price)
-        elif trcode == 'opt10081':
-            code = inputs['종목코드']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetDailyStockDataAsDataFrame(code, dtend, dtbegin, adjusted_price=adjusted_price)
-        elif trcode == 'opt10082':
-            code = inputs['종목코드']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetWeeklyStockDataAsDataFrame(code, dtend, dtbegin, adjusted_price=adjusted_price)
-        elif trcode == 'opt10083':
-            code = inputs['종목코드']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetMonthlyStockDataAsDataFrame(code, dtend, dtbegin, adjusted_price=adjusted_price)
-        elif trcode == 'opt10094':
-            code = inputs['종목코드']
-            adjusted_price = inputs.get('수정주가구분') == '1'
-            df = self.GetYearlyStockDataAsDataFrame(code, dtend, dtbegin, adjusted_price=adjusted_price)
+        if trcode == "opt10079":
+            code = inputs["종목코드"]
+            interval = inputs["틱범위"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetTickStockDataAsDataFrame(
+                code, interval, dtend, dtbegin, adjusted_price=adjusted_price
+            )
+        elif trcode == "opt10080":
+            code = inputs["종목코드"]
+            interval = inputs["틱범위"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetMinuteStockDataAsDataFrame(
+                code, interval, dtend, dtbegin, adjusted_price=adjusted_price
+            )
+        elif trcode == "opt10081":
+            code = inputs["종목코드"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetDailyStockDataAsDataFrame(
+                code, dtend, dtbegin, adjusted_price=adjusted_price
+            )
+        elif trcode == "opt10082":
+            code = inputs["종목코드"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetWeeklyStockDataAsDataFrame(
+                code, dtend, dtbegin, adjusted_price=adjusted_price
+            )
+        elif trcode == "opt10083":
+            code = inputs["종목코드"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetMonthlyStockDataAsDataFrame(
+                code, dtend, dtbegin, adjusted_price=adjusted_price
+            )
+        elif trcode == "opt10094":
+            code = inputs["종목코드"]
+            adjusted_price = inputs.get("수정주가구분") == "1"
+            df = self.GetYearlyStockDataAsDataFrame(
+                code, dtend, dtbegin, adjusted_price=adjusted_price
+            )
         else:
-            raise KiwoomOpenApiPlusError('Unexpected trcode %s' % trcode)
+            raise KiwoomOpenApiPlusError("Unexpected trcode %s" % trcode)
 
         candles = HistoricalPriceRecord.dict_records_from_dataframe(df)
-        response = {'candles': candles}
+        response = {"candles": candles}
         return response
 
     def get_positions(self, account):
         _summary, foreach = self.GetAccountEvaluationStatusAsSeriesAndDataFrame(account)
-        positions = [{
-            'instrument': tup.종목코드,
-            'side': 'buy',
-            'units': float(tup.보유수량),
-            'avgPrice': float(tup.매입금액) / float(tup.보유수량),
-        } for tup in foreach.itertuples()]
-        response = {'positions': positions}
+        positions = [
+            {
+                "instrument": tup.종목코드,
+                "side": "buy",
+                "units": float(tup.보유수량),
+                "avgPrice": float(tup.매입금액) / float(tup.보유수량),
+            }
+            for tup in foreach.itertuples()
+        ]
+        response = {"positions": positions}
         return response
 
     def get_account(self, account):
         summary, _foreach = self.GetAccountEvaluationStatusAsSeriesAndDataFrame(account)
         response = {
-            'marginAvail': float(summary['D+2추정예수금']),
-            'balance': float(summary['추정예탁자산']),
+            "marginAvail": float(summary["D+2추정예수금"]),
+            "balance": float(summary["추정예탁자산"]),
         }
         return response
 
     def create_order(self, account, **kwargs):
-        request_name = 'create_order(%s, %s)' % (account, kwargs)
-        screen_no = ''
+        request_name = "create_order({}, {})".format(account, kwargs)
+        screen_no = ""
         account_no = account
         order_type = {
-            'buy': 1,
-            'sell': 2,
-        }[kwargs['side']]
-        code = kwargs['instrument']
-        quantity = kwargs['units']
-        price = kwargs.get('price', 0)
+            "buy": 1,
+            "sell": 2,
+        }[kwargs["side"]]
+        code = kwargs["instrument"]
+        quantity = kwargs["units"]
+        price = kwargs.get("price", 0)
         quote_type = {
-            'limit': '00',
-            'market': '03',
-        }[kwargs['type']]
-        original_order_no = ''
+            "limit": "00",
+            "market": "03",
+        }[kwargs["type"]]
+        original_order_no = ""
         responses = self.OrderCall(
             request_name,
             screen_no,
@@ -189,20 +215,20 @@ class API:
         _tr = next(responses)
         accept = next(responses)
         accept_data = dict(zip(accept.single_data.names, accept.single_data.values))
-        result = {
-            'orderOpened': {'id': accept_data['주문번호']}
-        }
+        result = {"orderOpened": {"id": accept_data["주문번호"]}}
         return result
 
     def close_order(self, account, oid, size, dataname):
-        request_name = 'close_order(%s, %s, %s, %s)' % (account, oid, size, dataname)
-        screen_no = ''
+        request_name = "close_order({}, {}, {}, {})".format(
+            account, oid, size, dataname
+        )
+        screen_no = ""
         account_no = account
         order_type = 3 if size >= 0 else 4
         code = dataname
         quantity = 0
         price = 0
-        quote_type = ''
+        quote_type = ""
         original_order_no = oid
         responses = self.OrderCall(
             request_name,
@@ -220,31 +246,33 @@ class API:
         _accept = next(responses)
         confirm = next(responses)
         confirm_data = dict(zip(confirm.single_data.names, confirm.single_data.values))
-        result = {
-            'orderOpened': {'id': confirm_data['주문번호']}
-        }
+        result = {"orderOpened": {"id": confirm_data["주문번호"]}}
         return result
 
     def get_today_quotes_by_code(self, codes=None):
         if codes is None:
             codes = self._codes
         df = self.GetStockQuoteInfoAsDataFrame(codes)
-        dt = pd.to_datetime(df['일자'].str.cat(df['체결시간']), format='%Y%m%d%H%M%S').dt.tz_localize(self._krx_timezone)
+        dt = pd.to_datetime(
+            df["일자"].str.cat(df["체결시간"]), format="%Y%m%d%H%M%S"
+        ).dt.tz_localize(self._krx_timezone)
         dt = dt.astype(np.int64) // 10 ** 3
-        df = pd.DataFrame({
-            'dataname': df['종목코드'],
-            'time': dt,
-            'open': df['시가'].astype(float).abs(),
-            'high': df['고가'].astype(float).abs(),
-            'low': df['저가'].astype(float).abs(),
-            'close': df['종가'].astype(float).abs(),
-            'volume': df['거래량'].astype(float).abs(),
-        })
+        df = pd.DataFrame(
+            {
+                "dataname": df["종목코드"],
+                "time": dt,
+                "open": df["시가"].astype(float).abs(),
+                "high": df["고가"].astype(float).abs(),
+                "low": df["저가"].astype(float).abs(),
+                "close": df["종가"].astype(float).abs(),
+                "volume": df["거래량"].astype(float).abs(),
+            }
+        )
         msgs = {tup.dataname: tup._asdict() for tup in df.itertuples(index=False)}
         return msgs
 
-class MetaSingleton(MetaParams):
 
+class MetaSingleton(MetaParams):
     def __init__(cls, clsname, bases, dct):
         super().__init__(clsname, bases, dct)
         cls._singleton = None
@@ -255,7 +283,10 @@ class MetaSingleton(MetaParams):
 
         return cls._singleton
 
-class MetaKiwoomOpenApiPlusStore(type(Logging), MetaSingleton): pass
+
+class MetaKiwoomOpenApiPlusStore(type(Logging), MetaSingleton):
+    pass
+
 
 class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
     # pylint: disable=protected-access
@@ -264,8 +295,8 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
     DataCls = None  # data class will auto register
 
     params = (
-        ('account', ''),
-        ('account_tmout', 60.0), # TODO: 60초마다 TR 을 날리는데 정말 이게 필요한가?
+        ("account", ""),
+        ("account_tmout", 60.0),  # TODO: 60초마다 TR 을 날리는데 정말 이게 필요한가?
     )
 
     _DTEPOCH = datetime.datetime(1970, 1, 1)
@@ -274,15 +305,17 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
     def getdata(cls, *args, **kwargs):
         if cls.DataCls is None:
             from koapy.backtrader.KiwoomOpenApiPlusData import KiwoomOpenApiPlusData
+
             cls.DataCls = KiwoomOpenApiPlusData
-        return cls.DataCls(*args, **kwargs) # pylint: disable=not-callable
+        return cls.DataCls(*args, **kwargs)  # pylint: disable=not-callable
 
     @classmethod
     def getbroker(cls, *args, **kwargs):
         if cls.BrokerCls is None:
             from koapy.backtrader.KiwoomOpenApiPlusBroker import KiwoomOpenApiPlusBroker
+
             cls.BrokerCls = KiwoomOpenApiPlusBroker
-        return cls.BrokerCls(*args, **kwargs) # pylint: disable=not-callable
+        return cls.BrokerCls(*args, **kwargs)  # pylint: disable=not-callable
 
     def __init__(self, context=None):
         super().__init__()
@@ -327,14 +360,16 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
     def start(self, data=None, broker=None):
         if not self._ever_started:
             self._ever_started = True
-            self._today_quotes_by_code = self.api.get_today_quotes_by_code(self.datanames)
+            self._today_quotes_by_code = self.api.get_today_quotes_by_code(
+                self.datanames
+            )
             self._today_quotes_by_code_done.set()
 
         if data is None and broker is None:
             return
 
         if data is not None:
-            self._env = data._env # pylint: disable=protected-access
+            self._env = data._env  # pylint: disable=protected-access
             self.datas.append(data)
 
             if self.broker is not None:
@@ -365,23 +400,32 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
         return self._tmoffset
 
     _GRANULARITIES = {
-        (TimeFrame.Ticks, 1):    ('opt10079', {'종목코드': '', '틱범위': '1', '수정주가구분': '1'}),
-        (TimeFrame.Ticks, 3):    ('opt10079', {'종목코드': '', '틱범위': '3', '수정주가구분': '1'}),
-        (TimeFrame.Ticks, 5):    ('opt10079', {'종목코드': '', '틱범위': '5', '수정주가구분': '1'}),
-        (TimeFrame.Ticks, 10):   ('opt10079', {'종목코드': '', '틱범위': '10', '수정주가구분': '1'}),
-        (TimeFrame.Ticks, 30):   ('opt10079', {'종목코드': '', '틱범위': '30', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 1):  ('opt10080', {'종목코드': '', '틱범위': '1', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 3):  ('opt10080', {'종목코드': '', '틱범위': '3', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 5):  ('opt10080', {'종목코드': '', '틱범위': '5', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 10): ('opt10080', {'종목코드': '', '틱범위': '10', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 15): ('opt10080', {'종목코드': '', '틱범위': '15', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 30): ('opt10080', {'종목코드': '', '틱범위': '30', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 45): ('opt10080', {'종목코드': '', '틱범위': '45', '수정주가구분': '1'}),
-        (TimeFrame.Minutes, 60): ('opt10080', {'종목코드': '', '틱범위': '60', '수정주가구분': '1'}),
-        (TimeFrame.Days, 1):     ('opt10081', {'종목코드': '', '기준일자': '', '수정주가구분': '1'}),
-        (TimeFrame.Weeks, 1):    ('opt10082', {'종목코드': '', '기준일자': '', '끝일자': '', '수정주가구분': '1'}),
-        (TimeFrame.Months, 1):   ('opt10083', {'종목코드': '', '기준일자': '', '끝일자': '', '수정주가구분': '1'}),
-        (TimeFrame.Years, 1):    ('opt10094', {'종목코드': '', '기준일자': '', '끝일자': '', '수정주가구분': '1'}),
+        (TimeFrame.Ticks, 1): ("opt10079", {"종목코드": "", "틱범위": "1", "수정주가구분": "1"}),
+        (TimeFrame.Ticks, 3): ("opt10079", {"종목코드": "", "틱범위": "3", "수정주가구분": "1"}),
+        (TimeFrame.Ticks, 5): ("opt10079", {"종목코드": "", "틱범위": "5", "수정주가구분": "1"}),
+        (TimeFrame.Ticks, 10): ("opt10079", {"종목코드": "", "틱범위": "10", "수정주가구분": "1"}),
+        (TimeFrame.Ticks, 30): ("opt10079", {"종목코드": "", "틱범위": "30", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 1): ("opt10080", {"종목코드": "", "틱범위": "1", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 3): ("opt10080", {"종목코드": "", "틱범위": "3", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 5): ("opt10080", {"종목코드": "", "틱범위": "5", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 10): ("opt10080", {"종목코드": "", "틱범위": "10", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 15): ("opt10080", {"종목코드": "", "틱범위": "15", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 30): ("opt10080", {"종목코드": "", "틱범위": "30", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 45): ("opt10080", {"종목코드": "", "틱범위": "45", "수정주가구분": "1"}),
+        (TimeFrame.Minutes, 60): ("opt10080", {"종목코드": "", "틱범위": "60", "수정주가구분": "1"}),
+        (TimeFrame.Days, 1): ("opt10081", {"종목코드": "", "기준일자": "", "수정주가구분": "1"}),
+        (TimeFrame.Weeks, 1): (
+            "opt10082",
+            {"종목코드": "", "기준일자": "", "끝일자": "", "수정주가구분": "1"},
+        ),
+        (TimeFrame.Months, 1): (
+            "opt10083",
+            {"종목코드": "", "기준일자": "", "끝일자": "", "수정주가구분": "1"},
+        ),
+        (TimeFrame.Years, 1): (
+            "opt10094",
+            {"종목코드": "", "기준일자": "", "끝일자": "", "수정주가구분": "1"},
+        ),
     }
 
     def get_granularity(self, timeframe, compression, default=None):
@@ -393,13 +437,13 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
         except KiwoomOpenApiPlusError:
             return None
 
-        i = insts.get('instruments', [{}])
+        i = insts.get("instruments", [{}])
         inst = i[0] if len(i) else None
         return inst
 
     def streaming_events(self, tmout=None):
         q = queue.Queue()
-        kwargs = {'q': q, 'tmout': tmout}
+        kwargs = {"q": q, "tmout": tmout}
 
         t = threading.Thread(target=self._t_streaming_listener, kwargs=kwargs)
         t.daemon = True
@@ -421,10 +465,12 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
         streamer = KiwoomOpenApiPlusEventStreamer(self.api, q)
         streamer.events()
 
-    def candles(self, dataname, dtbegin, dtend, timeframe, compression): # pylint: disable=unused-argument
+    def candles(
+        self, dataname, dtbegin, dtend, timeframe, compression
+    ):  # pylint: disable=unused-argument
         kwargs = locals().copy()
-        kwargs.pop('self')
-        kwargs['q'] = q = queue.Queue()
+        kwargs.pop("self")
+        kwargs["q"] = q = queue.Queue()
         t = threading.Thread(target=self._t_candles, kwargs=kwargs)
         t.daemon = True
         t.start()
@@ -439,15 +485,15 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             return
 
         inputs = inputs.copy()
-        inputs['종목코드'] = dataname
+        inputs["종목코드"] = dataname
 
         if dtbegin is not None:
-            if '끝일자' in inputs:
-                inputs['끝일자'] = dtbegin.strftime('%Y%m%d')
+            if "끝일자" in inputs:
+                inputs["끝일자"] = dtbegin.strftime("%Y%m%d")
 
         if dtend is not None:
-            if '기준일자' in inputs:
-                inputs['기준일자'] = dtend.strftime('%Y%m%d')
+            if "기준일자" in inputs:
+                inputs["기준일자"] = dtend.strftime("%Y%m%d")
 
         try:
             response = self.api.get_history(trcode, inputs, dtbegin, dtend)
@@ -456,14 +502,14 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             q.put(None)
             return
 
-        for candle in response.get('candles', []):
+        for candle in response.get("candles", []):
             q.put(candle)
 
         q.put({})
 
     def streaming_prices(self, dataname, tmout=None):
         q = queue.Queue()
-        kwargs = {'q': q, 'dataname': dataname, 'tmout': tmout}
+        kwargs = {"q": q, "dataname": dataname, "tmout": tmout}
         t = threading.Thread(target=self._t_streaming_prices, kwargs=kwargs)
         t.daemon = True
         t.start()
@@ -487,10 +533,9 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
         except KiwoomOpenApiPlusError:
             return None
 
-        poslist = positions.get('positions', [])
+        poslist = positions.get("positions", [])
         return poslist
 
-
     def broker_threads(self):
         self.q_account = queue.Queue()
         self.q_account.put(True)  # force an immediate update
@@ -522,65 +567,68 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
 
             try:
                 accinfo = self.api.get_account(self.p.account)
-            except Exception as e: # pylint: disable=broad-except
+            except Exception as e:  # pylint: disable=broad-except
                 self.put_notification(e)
                 continue
 
             try:
-                self._cash = accinfo['marginAvail']
-                self._value = accinfo['balance']
+                self._cash = accinfo["marginAvail"]
+                self._value = accinfo["balance"]
             except KeyError:
                 pass
 
             self._evt_acct.set()
 
-
     # from below, it's related to processing orders
 
-
     _ORDEREXECS = {
-        bt.Order.Market: 'market',
-        bt.Order.Limit: 'limit',
-        bt.Order.Stop: 'stop',
-        bt.Order.StopLimit: 'stop',
+        bt.Order.Market: "market",
+        bt.Order.Limit: "limit",
+        bt.Order.Stop: "stop",
+        bt.Order.StopLimit: "stop",
     }
 
     def order_create(self, order, stopside=None, takeside=None, **kwargs):
         okwargs = dict()
-        okwargs['instrument'] = order.data._dataname
-        okwargs['units'] = abs(order.created.size)
-        okwargs['side'] = 'buy' if order.isbuy() else 'sell'
-        okwargs['type'] = self._ORDEREXECS[order.exectype]
+        okwargs["instrument"] = order.data._dataname
+        okwargs["units"] = abs(order.created.size)
+        okwargs["side"] = "buy" if order.isbuy() else "sell"
+        okwargs["type"] = self._ORDEREXECS[order.exectype]
         if order.exectype != bt.Order.Market:
-            okwargs['price'] = order.created.price
+            okwargs["price"] = order.created.price
             if order.valid is None:
                 # 1 year and datetime.max fail ... 1 month works
                 valid = datetime.datetime.utcnow() + datetime.timedelta(days=30)
             else:
                 valid = order.data.num2date(order.valid)
                 # To timestamp with seconds precision
-            okwargs['expiry'] = int((valid - self._DTEPOCH).total_seconds())
+            okwargs["expiry"] = int((valid - self._DTEPOCH).total_seconds())
 
         if order.exectype == bt.Order.StopLimit:
-            okwargs['lowerBound'] = order.created.pricelimit
-            okwargs['upperBound'] = order.created.pricelimit
+            okwargs["lowerBound"] = order.created.pricelimit
+            okwargs["upperBound"] = order.created.pricelimit
 
         if order.exectype == bt.Order.StopTrail:
-            okwargs['trailingStop'] = order.trailamount
+            okwargs["trailingStop"] = order.trailamount
 
         if stopside is not None:
-            okwargs['stopLoss'] = stopside.price
+            okwargs["stopLoss"] = stopside.price
 
         if takeside is not None:
-            okwargs['takeProfit'] = takeside.price
+            okwargs["takeProfit"] = takeside.price
 
         okwargs.update(**kwargs)  # anything from the user
 
-        self.q_ordercreate.put((order.ref, okwargs,))
+        self.q_ordercreate.put(
+            (
+                order.ref,
+                okwargs,
+            )
+        )
         return order
 
-    _OIDSINGLE = ['orderOpened', 'tradeOpened', 'tradeReduced']
-    _OIDMULTIPLE = ['tradesClosed']
+    _OIDSINGLE = ["orderOpened", "tradeOpened", "tradeReduced"]
+    _OIDMULTIPLE = ["tradesClosed"]
 
     def _t_order_create(self):
         while True:
@@ -592,7 +640,9 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             try:
                 o = self.api.create_order(self.p.account, **okwargs)
             except Exception as e:
-                self.logger.exception('Exception while create_order(%s, %s)', self.p.account, okwargs)
+                self.logger.exception(
+                    "Exception while create_order(%s, %s)", self.p.account, okwargs
+                )
                 self.put_notification(e)
                 self.broker._reject(oref)
                 return
@@ -601,22 +651,22 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             # match them (as executions) to the order generated here
             oids = list()
             for oidfield in self._OIDSINGLE:
-                if oidfield in o and 'id' in o[oidfield]:
-                    oids.append(o[oidfield]['id'])
+                if oidfield in o and "id" in o[oidfield]:
+                    oids.append(o[oidfield]["id"])
 
             for oidfield in self._OIDMULTIPLE:
                 if oidfield in o:
                     for suboidfield in o[oidfield]:
-                        oids.append(suboidfield['id'])
+                        oids.append(suboidfield["id"])
 
             if not oids:
-                self.logger.warning('Rejecting %s because no oids specified', oref)
+                self.logger.warning("Rejecting %s because no oids specified", oref)
                 self.broker._reject(oref)
                 return
 
             self._orders[oref] = oids[0]
             self.broker._submit(oref)
-            if okwargs['type'] == 'market':
+            if okwargs["type"] == "market":
                 self.broker._accept(oref)  # taken immediately
 
             for oid in oids:
@@ -648,42 +698,42 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             try:
                 o = self.api.close_order(self.p.account, oid, size, dataname)
             except Exception as e:
-                self.logger.exception('Failed to close order')
+                self.logger.exception("Failed to close order")
                 continue  # not cancelled - FIXME: notify
 
             self.broker._cancel(oref)
 
     _X_ORDER_CREATE = (
-        'STOP_ORDER_CREATE',
-        'LIMIT_ORDER_CREATE',
-        'MARKET_IF_TOUCHED_ORDER_CREATE',
+        "STOP_ORDER_CREATE",
+        "LIMIT_ORDER_CREATE",
+        "MARKET_IF_TOUCHED_ORDER_CREATE",
     )
 
     def _transaction(self, trans):
         # Invoked from Streaming Events. May actually receive an event for an
         # oid which has not yet been returned after creating an order. Hence
         # store if not yet seen, else forward to processer
-        ttype = trans['type']
-        if ttype == 'MARKET_ORDER_CREATE':
+        ttype = trans["type"]
+        if ttype == "MARKET_ORDER_CREATE":
             try:
-                oid = trans['tradeReduced']['id']
+                oid = trans["tradeReduced"]["id"]
             except KeyError:
                 try:
-                    oid = trans['tradeOpened']['id']
+                    oid = trans["tradeOpened"]["id"]
                 except KeyError:
                     return  # cannot do anything else
 
         elif ttype in self._X_ORDER_CREATE:
-            oid = trans['id']
-        elif ttype == 'ORDER_FILLED':
-            oid = trans['orderId']
+            oid = trans["id"]
+        elif ttype == "ORDER_FILLED":
+            oid = trans["orderId"]
 
-        elif ttype == 'ORDER_CANCEL':
-            oid = trans['orderId']
+        elif ttype == "ORDER_CANCEL":
+            oid = trans["orderId"]
 
-        elif ttype == 'TRADE_CLOSE':
-            oid = trans['id']
-            pid = trans['tradeId']
+        elif ttype == "TRADE_CLOSE":
+            oid = trans["id"]
+            pid = trans["tradeId"]
             if pid in self._orders and False:  # Know nothing about trade
                 return  # can do nothing
 
@@ -692,18 +742,20 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             # closes an existing position related to order with id -> pid
             # COULD BE DONE: Generate a fake counter order to gracefully
             # close the existing position
-            msg = ('Received TRADE_CLOSE for unknown order, possibly generated'
-                   ' over a different client or GUI')
+            msg = (
+                "Received TRADE_CLOSE for unknown order, possibly generated"
+                " over a different client or GUI"
+            )
             self.put_notification(msg, trans)
             return
 
         else:  # Go aways gracefully
             try:
-                oid = trans['id']
+                oid = trans["id"]
             except KeyError:
-                oid = 'None'
+                oid = "None"
 
-            msg = 'Received {} with oid {}. Unknown situation'
+            msg = "Received {} with oid {}. Unknown situation"
             msg = msg.format(ttype, oid)
             self.put_notification(msg, trans)
             return
@@ -715,11 +767,11 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
             self._transpend[oid].append(trans)
 
     _X_ORDER_FILLED = (
-        'MARKET_ORDER_CREATE',
-        'ORDER_FILLED',
-        'TAKE_PROFIT_FILLED',
-        'STOP_LOSS_FILLED',
-        'TRAILING_STOP_FILLED',
+        "MARKET_ORDER_CREATE",
+        "ORDER_FILLED",
+        "TAKE_PROFIT_FILLED",
+        "STOP_LOSS_FILLED",
+        "TRAILING_STOP_FILLED",
     )
 
     def _process_transaction(self, oid, trans):
@@ -728,27 +780,27 @@ class KiwoomOpenApiPlusStore(Logging, metaclass=MetaKiwoomOpenApiPlusStore):
         except KeyError:
             return
 
-        ttype = trans['type']
+        ttype = trans["type"]
 
         if ttype in self._X_ORDER_FILLED:
-            size = trans['units']
-            if trans['side'] == 'sell':
+            size = trans["units"]
+            if trans["side"] == "sell":
                 size = -size
-            price = trans['price']
+            price = trans["price"]
             self.broker._fill(oref, size, price, ttype=ttype)
 
         elif ttype in self._X_ORDER_CREATE:
             self.broker._accept(oref)
             self._ordersrev[oid] = oref
 
-        elif ttype in 'ORDER_CANCEL':
-            reason = trans['reason']
-            if reason == 'ORDER_FILLED':
+        elif ttype in "ORDER_CANCEL":
+            reason = trans["reason"]
+            if reason == "ORDER_FILLED":
                 pass  # individual execs have done the job
-            elif reason == 'TIME_IN_FORCE_EXPIRED':
+            elif reason == "TIME_IN_FORCE_EXPIRED":
                 self.broker._expire(oref)
-            elif reason == 'CLIENT_REQUEST':
+            elif reason == "CLIENT_REQUEST":
                 self.broker._cancel(oref)
             else:  # default action ... if nothing else
-                self.logger.warning('Rejecting %s since it\'s canceled', oref)
+                self.logger.warning("Rejecting %s since it's canceled", oref)
                 self.broker._reject(oref)
